#[non_exhaustive]pub enum CostError {
WrongType {
id: u64,
actual: String,
expected: &'static str,
},
MissingReference {
from: u64,
to: u64,
},
}Expand description
Failures specific to interpreting cost data.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
WrongType
An entity was expected to be a cost entity but is not.
Fields
MissingReference
A referenced cost value or quantity does not exist.